---
title: 결제대행사별 서비스 목록
category: 서비스 종류 (결제대행사별 지원서비스) > 결제대행사별 지원서비스 > 결제대행사별 지원서비스
seo:
  title: 결제대행사별 서비스 목록
  description: 포트원이 소개하는 결제대행사별 지원서비스와 각 결제수단의 종류, 연동방식, 본인인증 종류까지 한번에 확인해보세요.
  keywords:
    - 결제대행사
tags:
  - 공통
pgCompanies:
  - 공통
searchTags:
  - 모듈
  - 결제수단
  - 지원하는PG사
  - PG사지원
  - PG사목록
  - 지원PG사
  - 지원수단
---

<Callout content="포트원에서 지원드리는 결제대행사 목록과 지원 가능한 결제수단 및 연동방식을 안내드립니다.
결제대행사에 따라 **구 버전**의 모듈과 **신 버전**의 모듈이 구분되는 경우가 있으며.
**신 버전이 결제대행사의 최신 모듈로 구현된 버전입니다.**" />

## 결제대행사

### **나이스페이먼츠**

#### **신모듈**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌, 상품권
  - 정기결제 : 카드
  - 수기결제 : 카드, 가상계좌
  - 간편결제 허브형 : 카카오페이, 네이버페이, 페이코, SSGpay, Lpay, 삼성페이, 애플페이, 11Pay

* **연동방식** : 결제창(SDK) 일반결제, API 수기(키인)결제, API 정기결제

- **지원가능 연동 모듈** : V1, V2

#### **구모듈**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌, 상품권
  - 정기결제 : 카드
  - 수기결제 : 카드, 가상계좌
  - 간편결제 허브형 : 카카오페이

* **연동방식** : 결제창(SDK) 일반결제, API 수기(키인)결제, API 정기결제

- **지원가능 연동 모듈** : V1

### **KG 이니시스**

#### **결제**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌, 휴대폰 소액결제, 상품권
  - 정기결제 : 카드
  - 수기결제 : 카드, 가상계좌
  - 간편결제 허브형 : 카카오페이, 네이버페이, 페이코, SSGpay, Lpay, 삼성페이, 애플페이, 토스페이

* **연동방식** : 결제창(SDK) 일반결제, API 수기(키인)결제, 결제창(SDK) 정기결제, API 정기결제

- **지원가능 연동 모듈** : V1, V2

#### **본인인증**

- **인증수단** :
  - 통합인증 : 네이버, PASS, 토스, 페이코, 카카오, 금융인증서, 삼성패스, 은행 등

* **연동방식** : 결제창(SDK) 본인인증

- **지원가능 연동 모듈** : V1

### **NHN KCP**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌, 휴대폰 소액결제, 상품권
  - 정기결제 : 카드
  - 수기결제 : 카드
  - 간편결제 허브형 : 카카오페이, 네이버페이, 페이코, SSGpay, Lpay, 삼성페이, 애플페이

* **연동방식** : 결제창(SDK) 일반결제, 결제창(SDK)/API 수기(키인)결제, 결제창(SDK)/API 정기결제

- **지원가능 연동 모듈** : V1, V2(상반기 내 지원 예정)

### **KSNET**

- **결제수단** :
  - 일반결제 : 카드, 실시간계좌이체, 가상계좌, 휴대폰 소액결제
  - 정기결제 : 카드
  - 수기결제 : 카드, 가상계좌
  - 간편결제 허브형 : 카카오페이, 네이버페이, 페이코, SSGpay, Lpay

* **연동방식** : 결제창(SDK) 일반결제, API 수기(키인)결제, API 정기결제

- **지원가능 연동 모듈** :  V1, V2

### **스마트로**

#### **신모듈**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌
  - 정기결제 : 카드
  - 수기결제 : 가상계좌
  - 간편결제 허브형 : 카카오페이, 네이버페이, 페이코, Lpay, Pinpay

* **연동방식** : 결제창(SDK) 일반결제, API 수기(키인)결제, 결제창(SDK)/API 정기결제

- **지원가능 연동 모듈** : V1, V2

#### **구모듈**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌

* **연동방식** : 결제창(SDK) 일반결제

- **지원가능 연동 모듈** : V1

### 토스페이먼츠

#### **신모듈**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌,휴대폰 소액결제, 상품권
  - 정기결제 : 카드
  - 수기결제 : 카드,가상계좌
  - 간편결제 허브형 : 카카오페이, 네이버페이, 페이코, SSGpay, Lpay, 삼성페이, 애플페이, 토스페이

* **연동방식** : 결제창(SDK) 일반결제 , 결제창(SDK) /API 수기(키인)결제 , 결제창(SDK)/API 정기결제

- **지원가능 연동 모듈** :  V1, V2

#### **구모듈**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌, 휴대폰 소액결제, 상품권
  - 간편결제 허브형 : 카카오페이, 네이버페이 페이코, SSGpay, Lpay , 삼성페이. 애플페이, 토스페이

* **연동방식** : 결제창(SDK) 일반결제

- **지원가능 연동 모듈** : V1

#### 브랜드페이

- **결제수단** :
  - 일반결제 : 카드, 계좌

* **연동방식 :** 결제창(SDK) 일반결제

- \*\*지원가능 연동모듈 \*\*: V1

### **키움페이**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌
  - 정기결제 : 카드
  - 수기결제 : 카드

* **연동방식** : 결제창(SDK) 일반결제, API 수기(키인)결제, API 정기결제

- **지원가능 연동 모듈** : V1

### **KG 모빌리언스**

- **결제수단** :
  - 일반결제 : 카드, 휴대폰 소액결제
  - 정기결제 : 휴대폰 소액결제

* **연동방식** : 결제창(SDK) 일반결제, 결제창(SDK) 정기결제

- **지원가능 연동 모듈** : V1

### **헥토파이낸셜**

#### **일반**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌, 휴대폰 소액결
  - 정기결제 : 카드
  - 수기결제 : 카드, 가상계좌

* **연동방식** : 결제창(SDK) 일반결제, API 수기(키인)결제, API 정기결제

- **지원가능 연동 모듈** : V1

#### **내통장결제**

- **결제수단** :
  - 일반결제 : 계좌
  - 정기결제 : 계좌

* **연동방식** : 결제창(SDK) 일반결제, 결제창(SDK) 정기결제

- **지원가능 연동 모듈** : V1

### **이지페이(KICC)**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌, 휴대폰 소액결제
  - 정기결제 : 카드

* **연동방식** : 결제창(SDK) 일반결제, API 정기결제

- **지원가능 연동 모듈** : V1

### **다날**

#### **결제**

<Callout content="다날의 경우 간편결제는 결제창 안에서 선택하는 방식으로만 이용가능 합니다." title="참고사항" icon="💡" />

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌, 휴대폰 소액결제, 상품권
  - 정기결제 : 카드, 휴대폰 소액결제

* **연동방식** : 결제창(SDK) 일반결제, 결제창(SDK) 정기결제

- **지원가능 연동 모듈** : V1

#### **본인인증**

- **인증수단** :
  - 휴대폰 본인인증 : SMS, PASS

* **연동방식** : 결제창(SDK) 본인인증, API 본인인증

- **지원가능 연동 모듈** : V1, V2

### **웰컴페이먼츠**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌, 휴대폰 소액결제, 상품권
  - 정기결제 : 카드, 휴대폰 소액결제
  - 수기결제 : 카드, 가상계좌
  - 간편결제 허브형 : 카카오페이, 페이코, Lpay, 토스페이

* **연동방식** : 결제창(SDK) 일반결제, API 수기(키인)결제, 결제창(SDK)/API 정기결제

- **지원가능 연동 모듈** : V1

### **한국결제네트웍스(KPN)**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌, 휴대폰 소액결제
  - 정기결제 : 카드
  - 수기결제 : 카드, 가상계좌
  - 간편결제 허브형 : 카카오페이, 네이버페이, 페이코, 삼성페이, 토스페이

* **연동방식** : 결제창(SDK) 일반결제, API 수기(키인)결제, 결제창(SDK)/API 정기결제

- **지원가능 연동 모듈** : V2

## 간편결제사

### **카카오페이**

- **결제수단** :
  - 일반결제 : 신용카드, 카카오머니
  - 정기결제 : 신용카드, 카카오머니

* **연동방식** : 결제창(SDK) 일반결제, 결제창(SDK) 정기결제

- **지원가능 연동 모듈** : V1, V2

### **네이버페이 결제형**

- **결제수단** :
  - 일반결제: 카드, 계좌, 네이버머니, 네이버포인트
  - 정기결제: 카드, 계좌, 네이버머니, 네이버포인트

* **연동방식** : 결제창(SDK) 일반결제, 결제창(SDK) 정기결제

- **지원가능 연동 모듈** : V1, V2

### **네이버페이 주문형**

- **결제수단** :
  - 일반결제 : 카드, 실시간 계좌이체, 가상계좌, 휴대폰 소액결제, 네이버포인트, 네이버머니, 삼성페이

* **연동방식** : 결제창(SDK) 일반결제

- **지원가능 연동 모듈** : V1

### **페이코**

- **결제수단** :
  - 일반결제 : 신용카드, 페이코 포인트, 페이코 쿠폰
  - 정기결제 : 신용카드, 페이코 포인트

* **연동방식** : 결제창(SDK) 일반결제, 결제창(SDK) 정기결제

- **지원가능 연동 모듈** : V1

### **토스페이**

- **결제수단** :
  - 일반결제 : 카드, 계좌, 토스머니
  - 정기결제 : 카드, 계좌, 토스머니

* **연동방식** : 결제창(SDK) 일반결제, 결제창(SDK) 정기결제

- **지원가능 연동 모듈** : V1, V2(상반기 내 지원 예정)

### **스마일페이**

- **결제수단** :
  - 일반결제 : 카드, 계좌, 스마일캐시

* **연동방식** : 결제창(SDK) 일반결제

- **지원가능 연동 모듈** : V1

### **하이픈**

- **결제수단** :
  - 바로간편계좌

* **연동방식** : 결제창(SDK) 일반결제

- **지원가능 연동 모듈** : V1, V2

## 해외 결제 대행사

### **페이먼트월**

- **결제수단** :
  - 일반결제 : 카드 / 실시간 계좌이체 / 가상계좌 / 핸드폰 소액결제 / 상품권 / 선불수단 외 기타 해외 현지 결제수단
  - 정기결제 : 해외카드(비자,마스터,JCB,Amex)

* **연동방식** : 결제창(SDK) 일반결제, 결제창(SDK)/API 정기결제

- **지원가능 연동 모듈** : V1

### **엑심베이**

- **결제수단**
  - 일반결제 : 해외카드(비자,마스터,JCB,Amex), 유니온페이 / 위챗페이 / 알리페이플러스 / 일본편의점

* **연동방식** : 결제창(SDK) 일반결제

- **지원가능 연동 모듈** : V1

### **페이팔**

- **결제수단** :
  - 일반결제 : 카드, 계좌
  - 정기결제 : 카드, 계좌

* **연동방식** : 결제창(SDK) 일반결제, 결제창(SDK) 정기결제

- **지원가능 연동 모듈** : V1, V2
